@@ -4,10 +4,12 @@ use strict;
 use warnings;
 
 BEGIN {
-    # Windows can't change timezone inside Perl script
     if ($ENV{TEST_TZ}) {
         $ENV{TZ} = delete $ENV{TEST_TZ};
-        exec $^X (map { "-I\"$_\"" } @INC), $0, @ARGV;
+        # Windows can't change timezone inside Perl script
+        if ($^O eq 'MSWin32') {
+            exec { $^X } map "\"$_\"", $^X, (map "-I$_", @INC), $0, @ARGV;
+        }
     };
 }
 
